Components class abstract

An abstract interface for defining groups of WildnessBase components.

Constructors

Components()
Enable const constructor for subclasses.
const

Properties

components List<WildnessBase>
Returns the list of WildnessBase components.
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited