WildnessProperties constructor

const WildnessProperties({
  1. Brightness? forceThemeMode,
  2. Configuration components = const Configuration(),
  3. Configuration resources = const Configuration(),
  4. ScrollPhysics physics = const ClampingScrollPhysics(),
  5. double minScaleFactor = 0.5,
  6. double maxScaleFactor = 1.2,
})

Creates a wildnessProperties that's used to configure wildnessUI

The forceThemeMode will be used to set the theme, if you don't pass it, the system default setting is used fallback is light

Implementation

const WildnessProperties({
  this.forceThemeMode,
  this._components = const Configuration(),
  this._resources = const Configuration(),
  this.physics = const ClampingScrollPhysics(),
  this.minScaleFactor = 0.5,
  this.maxScaleFactor = 1.2,
});