theme/custom_default_theme library
Default Material theme configuration applied when integrating with Wildness.
Classes
- CustomDefaultTheme
- A wrapper widget that applies customized Material ThemeData styles harmonized with Wildness configuration properties like primary color and default text style.